@@ -2,25 +2,26 @@ from __future__ import annotations
 
 import contextlib
 import datetime
-import typing
-from typing import Literal
+from typing import Literal, TYPE_CHECKING
+from zoneinfo import ZoneInfo
 
 import numpy as np
 import pandas as pd
-import pytz
 
 from exchange_calendars import errors
 
-if typing.TYPE_CHECKING:
+if TYPE_CHECKING:
     from exchange_calendars import ExchangeCalendar
 
+UTC = ZoneInfo("UTC")
+
 NANOSECONDS_PER_MINUTE = int(6e10)
 
 NP_NAT = pd.NaT.value
 
 # Use Date type where input does not need to represent an actual session
 # and will be parsed by parse_date.
-Date = typing.Union[pd.Timestamp, str, int, float, datetime.datetime]
+Date = pd.Timestamp | str | int | float | datetime.datetime | datetime.date
 
 # Use Session type where input should represent an actual session and will
 # be parsed by parse_session.
@@ -28,7 +29,7 @@ Session = Date
 
 # Use Minute type where input does not need to represent an actual trading
 # minute and will be parsed by parse_timestamp.
-Minute = typing.Union[pd.Timestamp, str, int, float, datetime.datetime]
+Minute = pd.Timestamp | str | int | float | datetime.datetime
 
 # Use TradingMinute where input should represent a trading minute and will
 # be parsed by parse_trading_minute.
@@ -36,7 +37,6 @@ TradingMinute = Minute
 
 
 def next_divider_idx(dividers: np.ndarray, minute_val: int) -> int:
-
     divider_idx = np.searchsorted(dividers, minute_val, side="right")
     target = dividers[divider_idx]
 
@@ -48,7 +48,6 @@ def next_divider_idx(dividers: np.ndarray, minute_val: int) -> int:
 
 
 def previous_divider_idx(dividers: np.ndarray, minute_val: int) -> int:
-
     divider_idx = np.searchsorted(dividers, minute_val)
 
     if divider_idx == 0:
@@ -146,9 +145,9 @@ def to_utc(ts: pd.Timestamp) -> pd.Timestamp:
         Timestamp to return a copy of with timezone set to UTC.
     """
     try:
-        return ts.tz_convert(pytz.UTC)
+        return ts.tz_convert(UTC)
     except TypeError:
-        return ts.tz_localize(pytz.UTC)
+        return ts.tz_localize(UTC)
 
 
 def parse_timestamp(
@@ -189,9 +188,9 @@ def parse_timestamp(
         to minute resolution.
 
     utc : default: True
-        True - convert / set timezone to "UTC".
+        True - convert / set timezone to UTC.
         False - leave any timezone unchanged. Note, if timezone of
-        `timestamp` is "UTC" then will remain as "UTC".
+        `timestamp` is UTC then will remain as UTC.
 
     Raises
     ------
@@ -224,8 +223,8 @@ def parse_timestamp(
             else:
                 raise ValueError(msg) from e
 
-    if utc and ts.tz is not pytz.UTC:
-        ts = ts.tz_localize("UTC") if ts.tz is None else ts.tz_convert("UTC")
+    if utc and ts.tz is not UTC:
+        ts = ts.tz_localize(UTC) if ts.tz is None else ts.tz_convert(UTC)
 
     if ts.second or ts.microsecond or ts.nanosecond:
         if side is None and calendar is None:
@@ -236,9 +235,9 @@ def parse_timestamp(
             )
         side = side if side is not None else calendar.side
         if side == "left":
-            ts = ts.floor("T")
+            ts = ts.floor("min")
         elif side == "right":
-            ts = ts.ceil("T")
+            ts = ts.ceil("min")
         else:
             raise ValueError(
                 "`timestamp` cannot have a non-zero second (or more accurate)"
@@ -376,7 +375,7 @@ def parse_date(
 
     if ts.tz is not None:
         raise ValueError(
-            f"Parameter `{param_name}` received with timezone defined as '{ts.tz.zone}'"
+            f"Parameter `{param_name}` received with timezone defined as '{ts.tz.key}'"
             f" although a Date must be timezone naive."
         )
 
@@ -442,7 +441,11 @@ class _TradingIndex:
 
     Parameters
     ----------
-    All parameters as ExchangeCalendar.trading_index
+    All parameters as ExchangeCalendar.trading_index except:
+
+    align_pm
+        As 'align' parameter of `ExchangeCalendar.trading_index` although
+        applied exclusively to the post-break subsessions.
     """
 
     def __init__(
@@ -451,12 +454,13 @@ class _TradingIndex:
         start_: Date | Minute,
         end_: Date | Minute,
         period: pd.Timedelta,
-        # TODO Literal["left", "right", "both", "neither"] when min python 3.8...
-        closed: str,
+        closed: Literal["left", "right", "both", "neither"],
         force_close: bool,
         force_break_close: bool,
         curtail_overlaps: bool,
         ignore_breaks: bool,
+        align: pd.Timedelta,
+        align_pm: pd.Timedelta,
     ):
         self.closed = closed
         self.force_break_close = False if ignore_breaks else force_break_close
@@ -479,16 +483,27 @@ class _TradingIndex:
         slce = slice(slice_start, slice_end)
 
         self.interval_nanos = period.value
-        self.dtype = np.int64 if self.interval_nanos < 3000000000 else np.int32
-
-        self.opens = calendar.opens_nanos[slce]
         self.closes = calendar.closes_nanos[slce]
 
+        def align_opens(opens: pd.Series, align: pd.Timedelta) -> np.ndarray:
+            """Return opens as nanos shifted for alignment."""
+            opens = opens.dt.ceil(align)
+            return opens.values.astype(np.int64)
+
+        if align != pd.Timedelta(1, "min"):
+            self.opens = align_opens(calendar.opens[slce], align)
+        else:
+            self.opens = calendar.opens_nanos[slce]
+
         if ignore_breaks:
             self.has_break = False
         else:
             self.break_starts = calendar.break_starts_nanos[slce]
-            self.break_ends = calendar.break_ends_nanos[slce]
+
+            if align_pm != pd.Timedelta(1, "min"):
+                self.break_ends = align_opens(calendar.break_ends[slce], align_pm)
+            else:
+                self.break_ends = calendar.break_ends_nanos[slce]
 
             self.mask = self.break_starts != pd.NaT.value  # break mask
             self.has_break = self.mask.any()
@@ -560,7 +575,7 @@ class _TradingIndex:
 
         # evaluate number of indices for each session
         num_intervals = (end_nanos - start_nanos) / self.interval_nanos
-        num_indices = np.ceil(num_intervals).astype("int")
+        num_indices = np.ceil(num_intervals).astype("int64")
 
         if force_close:
             if self.closed_right:
@@ -580,7 +595,7 @@ class _TradingIndex:
         start = 0 if self.closed_left else 1
         func = np.vectorize(lambda stop: np.arange(start, stop), otypes=[np.ndarray])
         stop = num_indices if self.closed_left else num_indices + 1
-        ranges = np.concatenate(func(stop), axis=0, dtype=self.dtype)
+        ranges = np.concatenate(func(stop), axis=0, dtype=np.int64)
 
         # evaluate index as nano array
         base = start_nanos.repeat(num_indices)
@@ -612,7 +627,6 @@ class _TradingIndex:
         becoming unsynced with the corresponding left indices.
         """
         if self.has_break:
-
             # sessions with breaks
             index_am = self._create_index_for_sessions(
                 self.opens[self.mask],
@@ -662,7 +676,7 @@ class _TradingIndex:
         index = self._trading_index()
         if self.has_break:
             index.sort()
-        index = pd.DatetimeIndex(index, tz="UTC")
+        index = pd.DatetimeIndex(index, tz=UTC)
         return self.curtail_for_times(index)
 
     @contextlib.contextmanager
@@ -700,7 +714,7 @@ class _TradingIndex:
             else:
                 raise errors.IntervalsOverlapError()
 
-        left = pd.DatetimeIndex(left, tz="UTC")
-        right = pd.DatetimeIndex(right, tz="UTC")
+        left = pd.DatetimeIndex(left, tz=UTC)
+        right = pd.DatetimeIndex(right, tz=UTC)
         index = pd.IntervalIndex.from_arrays(left, right, self.closed)
         return self.curtail_for_times(index)
